@@ -9,16 +9,21 @@
 #'  Useful if \code{parsing_option} 1 is needed, but some abbreviations within the string need \code{parsing_option} 2.
 #'  Use this feature with care: One letter abbreviations and abbreviations next to each other may not be handled correctly, since those cases would introduce ambiguity in parsing.
 #'  
-#' @param sep_in (short for separator input) A regex supplied as a character (if not \code{NULL}), which will be wrapped internally
-#' into \code{stringr::regex()}. All matches will be replaced by underscores. Underscores can later turned into another separator via \code{sep_out}.
+#' @param sep_in (short for separator input) if character, is interpreted as a
+#'  regular expression (wrapped internally into \code{stringr::regex()}). 
+#'  The default value is a regular expression that matches any sequence of
+#'  non-alphanumeric values. All matches will be replaced by underscores 
+#'  (additionally to \code{"_"} and \code{" "}, for which this is always true, even
+#'  if \code{NULL} is supplied). These underscores are used internally to split
+#'  the strings into substrings and specify the word boundaries.
 #' 
 #' @param parsing_option An integer that will determine the parsing_option.
 #' \itemize{
 #'  \item{1: \code{RRRStudio -> RRR_Studio}}
 #'  \item{2: \code{RRRStudio -> RRRS_tudio}}
-#'  \item{3: parses like option 1 but suppresses "_" around non special characters.
-#'  In this way case conversion won't apply after these characters. See examples.}
-#'  \item{4: parses like option 1, but digits directly behind/in front non-digits, will stay as is.}
+#'  \item{3: This \code{parsing_option} will suppress the conversion after non-alphanumeric
+#'  values. See examples.}
+#'  \item{4: digits directly behind/in front non-digits, will stay as is.}
 #'  \item{any other integer <= 0: no parsing"}
 #'  }
 #' 
@@ -81,7 +86,7 @@
 
 to_snake_case <- function(string,
                           abbreviations = NULL,
-                          sep_in = NULL,
+                          sep_in = "[^[:alnum:]]",
                           parsing_option = 1,
                           transliterations = NULL,
                           sep_out = NULL,
@@ -107,7 +112,7 @@ to_snake_case <- function(string,
 
 to_lower_camel_case <- function(string,
                                 abbreviations = NULL,
-                                sep_in = NULL,
+                                sep_in = "[^[:alnum:]]",
                                 parsing_option = 1,
                                 transliterations = NULL, 
                                 sep_out = NULL,
@@ -133,7 +138,7 @@ to_lower_camel_case <- function(string,
 
 to_upper_camel_case <- function(string,
                                 abbreviations = NULL,
-                                sep_in = NULL,
+                                sep_in = "[^[:alnum:]]",
                                 parsing_option = 1,
                                 transliterations = NULL,
                                 sep_out = NULL,
@@ -159,7 +164,7 @@ to_upper_camel_case <- function(string,
 
 to_screaming_snake_case <- function(string,
                                     abbreviations = NULL,
-                                    sep_in = NULL,
+                                    sep_in = "[^[:alnum:]]",
                                     parsing_option = 1,
                                     transliterations = NULL,
                                     sep_out = NULL,
@@ -185,7 +190,7 @@ to_screaming_snake_case <- function(string,
 
 to_parsed_case <- function(string,
                            abbreviations = NULL,
-                           sep_in = NULL,
+                           sep_in = "[^[:alnum:]]",
                            parsing_option = 1,
                            transliterations = NULL,
                            sep_out = NULL,
@@ -211,7 +216,7 @@ to_parsed_case <- function(string,
 
 to_mixed_case <- function(string,
                           abbreviations = NULL,
-                          sep_in = NULL,
+                          sep_in = "[^[:alnum:]]",
                           parsing_option = 1,
                           transliterations = NULL,
                           sep_out = NULL,
@@ -237,7 +242,7 @@ to_mixed_case <- function(string,
 
 to_lower_upper_case <- function(string,
                                 abbreviations = NULL,
-                                sep_in = NULL,
+                                sep_in = "[^[:alnum:]]",
                                 parsing_option = 1,
                                 transliterations = NULL,
                                 sep_out = NULL,
@@ -263,7 +268,7 @@ to_lower_upper_case <- function(string,
 
 to_upper_lower_case <- function(string,
                                 abbreviations = NULL,
-                                sep_in = NULL,
+                                sep_in = "[^[:alnum:]]",
                                 parsing_option = 1,
                                 transliterations = NULL,
                                 sep_out = NULL,
@@ -289,7 +294,7 @@ to_upper_lower_case <- function(string,
 
 to_swap_case <- function(string,
                                 abbreviations = NULL,
-                                sep_in = NULL,
+                                sep_in = "[^[:alnum:]]",
                                 parsing_option = 1,
                                 transliterations = NULL,
                                 sep_out = NULL,
