@@ -2,15 +2,6 @@
 library(snakecase)
 to_any_case("veryComplicatedString")
 
-## ---- collapse = TRUE----------------------------------------------------
-to_any_case("malte.grosser@gmail.com")
-
-## ---- collapse = TRUE----------------------------------------------------
-to_any_case(names(iris), sep_in = "\\.")
-
-## ---- collapse = TRUE----------------------------------------------------
-to_any_case("Pi.Value:3.14", sep_in = ":|(?<!\\d)\\.")
-
 ## ---- collapse = TRUE----------------------------------------------------
 to_any_case(names(iris), sep_in = "\\.", case = "upper_camel", sep_out = " ")
 
