@@ -27,8 +27,8 @@ cases <-
     22 , "ssRRss"                    , "ss_R_Rss"                     , "ss_r_rss"                     , "ssRRss"                     , "SsRRss"                     , "SS_R_RSS",
     23 , "ssRRRR"                    , "ss_RRRR"                      , "ss_rrrr"                      , "ssRrrr"                     , "SsRrrr"                     , "SS_RRRR",
     24 , "thisIsSomeCamelCase"       , "this_Is_Some_Camel_Case"      , "this_is_some_camel_case"      , "thisIsSomeCamelCase"        , "ThisIsSomeCamelCase"        , "THIS_IS_SOME_CAMEL_CASE",
-    25 , "this.text"                 , "this.text"                    , "this.text"                    , "this.Text"                  , "This.Text"                  , "THIS.TEXT",
-    26 , "next.text"                 , "next.text"                    , "next.text"                    , "next.Text"                  , "Next.Text"                  , "NEXT.TEXT",
+    25 , "this.text"                 , "this_text"                    , "this_text"                    , "thisText"                   , "ThisText"                  , "THIS_TEXT",
+    26 , "next.text"                 , "next_text"                    , "next_text"                    , "nextText"                   , "NextText"                  , "NEXT_TEXT",
     27 , "zip code"                  , "zip_code"                     , "zip_code"                     , "zipCode"                    , "ZipCode"                    , "ZIP_CODE",
     28 , "state"                     , "state"                        , "state"                        , "state"                      , "State"                      , "STATE",
     29 , "final count"               , "final_count"                  , "final_count"                  , "finalCount"                 , "FinalCount"                 , "FINAL_COUNT",
@@ -39,7 +39,7 @@ cases <-
     34 , "ICUDays"                   , "ICU_Days"                     , "icu_days"                     , "icuDays"                    , "IcuDays"                    , "ICU_DAYS",
     35 , "SexCode"                   , "Sex_Code"                     , "sex_code"                     , "sexCode"                    , "SexCode"                    , "SEX_CODE",
     36 , "MAX_of_MLD"                , "MAX_of_MLD"                   , "max_of_mld"                   , "maxOfMld"                   , "MaxOfMld"                   , "MAX_OF_MLD",
-    37 , "Age.Group"                 , "Age.Group"                    , "age.group"                    , "age.Group"                  , "Age.Group"                  , "AGE.GROUP",
+    37 , "Age.Group"                 , "Age_Group"                    , "age_group"                    , "ageGroup"                   , "AgeGroup"                  , "AGE_GROUP",
     38 , "ThisText"                  , "This_Text"                    , "this_text"                    , "thisText"                   , "ThisText"                   , "THIS_TEXT",
     39 , "NextText"                  , "Next_Text"                    , "next_text"                    , "nextText"                   , "NextText"                   , "NEXT_TEXT",
     40 , "test_123_ 1 1"             , "test_123_1_1"                 , "test_123_1_1"                 , "test123_1_1"                , "Test123_1_1"                , "TEST_123_1_1"
